==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_mediastore/paginator.py <==
"""
Type annotations for mediastore service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_mediastore.client import MediaStoreClient
    from types_boto3_mediastore.paginator import (
        ListContainersPaginator,
    )

    session = Session()
    client: MediaStoreClient = session.client("mediastore")

    list_containers_paginator: ListContainersPaginator = client.get_paginator("list_containers")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListContainersInputListContainersPaginateTypeDef, ListContainersOutputTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListContainersPaginator",)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListContainersPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore/paginator/ListContainers.html#MediaStore.Paginator.ListContainers)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore/paginators/#listcontainerspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListContainersInputListContainersPaginateTypeDef]
    ) -> _PageIterator[ListContainersOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore/paginator/ListContainers.html#MediaStore.Paginator.ListContainers.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore/paginators/#listcontainerspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_mediastore/paginator.py <==
"""
Type annotations for mediastore service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_mediastore.client import MediaStoreClient
    from types_boto3_mediastore.paginator import (
        ListContainersPaginator,
    )

    session = Session()
    client: MediaStoreClient = session.client("mediastore")

    list_containers_paginator: ListContainersPaginator = client.get_paginator("list_containers")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListContainersInputPaginateTypeDef, ListContainersOutputTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListContainersPaginator",)


if TYPE_CHECKING:
    _ListContainersPaginatorBase = Paginator[ListContainersOutputTypeDef]
else:
    _ListContainersPaginatorBase = Paginator  # type: ignore[assignment]


class ListContainersPaginator(_ListContainersPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore/paginator/ListContainers.html#MediaStore.Paginator.ListContainers)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore/paginators/#listcontainerspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListContainersInputPaginateTypeDef]
    ) -> PageIterator[ListContainersOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore/paginator/ListContainers.html#MediaStore.Paginator.ListContainers.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore/paginators/#listcontainerspaginator)
        """
